Refreshable<T> class abstract

An interface for provider expressions that can be passed to ref.refresh

This differentiates:

ref.watch(provider);
ref.watch(provider.future);

from:

ref.watch(provider.select((value) => value));
Implemented types
Available extensions

Constructors

Refreshable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(Node node, void listener(T? previous, T next), {required void onError(Object error, StackTrace stackTrace)?, required void onDependencyMayHaveChanged()?, required bool fireImmediately}) ProviderSubscription<T>
Starts listening to this transformer
inherited
combineWith<T2>(ProviderListenable<T2> other) Provider<(T, T2)>

Available on ProviderListenable<T>, provided by the ProviderCombinerExtensions extension

Combines this provider with another provider.
mapValue<R>(R mapper(T value)) Provider<R>

Available on ProviderListenable<T>, provided by the ProviderCombinerExtensions extension

Maps this provider's value through a transformation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Node node) → T
Obtains the result of this provider expression without adding listener.
inherited
select<Selected>(Selected selector(T value)) ProviderListenable<Selected>
Partially listen to a provider.
inherited
toString() String
A string representation of this object.
inherited
whereValue(bool predicate(T value)) Provider<T>

Available on ProviderListenable<T>, provided by the ProviderCombinerExtensions extension

Filters this provider's rebuilds based on a predicate.

Operators

operator ==(Object other) bool
The equality operator.
inherited